Module buffer
rustmeter_
beacon_
core
0.2.0
Module buffer
Module Items
Structs
In crate rustmeter_
beacon_
core
rustmeter_beacon_core
Module
buffer
Structs

Buffer
Reader
Simple buffer reader for reading bytes from a slice
Buffer
Writer
Internal buffer writer for tracing events using a fixed-size buffer with uninitialized memory for efficiency