BufferReader

Struct BufferReader 

pub struct BufferReader<'a> { /* private fields */ }
Simple buffer reader for reading bytes from a slice

Implementations

Source

impl<'a> BufferReader<'a>

pub fn new(buffer: &'a [u8]) -> Self

pub fn len(&self) -> usize

pub fn read_byte(&mut self) -> Result<u8, ReadTracingError>

Reads a single byte from the buffer. Returns None if end of buffer is reached.

pub fn read_bytes(&mut self, length: usize) -> Result<&[u8], ReadTracingError>

Reads a slice of bytes of the given length from the buffer. Returns None if not enough data is available.

pub fn read_varint(&mut self) -> Result<u64, ReadTracingError>

Reads a LEB128 (VarInt) encoded u64.

pub fn read_u16(&mut self) -> Result<u16, ReadTracingError>

Reads a little-endian u16 from the buffer

pub fn read_u32(&mut self) -> Result<u32, ReadTracingError>

Reads a little-endian u32 from the buffer

pub fn read_u64(&mut self) -> Result<u64, ReadTracingError>

Reads a little-endian u64 from the buffer

pub fn get_position(&self) -> usize