Module tracing

Module tracing 

Enums

ReadTracingError

Functions

read_tracing_event
Reads a tracing event with timestamp from the provided buffer
write_tracing_data
Low-level function to write tracing data. Implemented in the target crate.
write_tracing_event
Serializes and writes a tracing event with timestamp to the tracing channel