EventPayload

Enum EventPayload 

pub enum EventPayload {
    EmbassyTaskReady {
        task_id: u16,
        executor_id: u3,
    },
    EmbassyTaskExecBegin {
        task_id: u16,
        executor_id: u3,
    },
    EmbassyTaskExecEnd {
        executor_id: u3,
    },
    EmbassyExecutorPollStart {
        executor_id: u3,
    },
    EmbassyExecutorIdle {
        executor_id: u3,
    },
    MonitorStart {
        monitor_id: u8,
    },
    MonitorEnd,
    MonitorValue {
        value_id: u8,
        value: MonitorValuePayload,
    },
    TypeDefinition(TypeDefinitionPayload),
    DataLossEvent {
        dropped_events: u32,
    },
    DefmtData {
        len: u8,
        data: *const u8,
    },
}

Variants



EmbassyTaskReady

Embassy Task is ready to be polled (Waker called). ExecutorID will also be included

Fields

task_id: u16
executor_id: u3


EmbassyTaskExecBegin

Embassy Task execution began (poll called). ExecutorID will also be included

Fields

task_id: u16
executor_id: u3


EmbassyTaskExecEnd

Embassy Task execution ended (returned Poll::Ready or yielded Poll::Pending). ExecutorID is included because it is shorter to transmit than TaskID and we know the executor from the TaskExecBegin event.

Fields

executor_id: u3


EmbassyExecutorPollStart

Embassy Executor started polling tasks. ExecutorID is included because it is the only identifier for the executor.

Fields

executor_id: u3


EmbassyExecutorIdle

Embassy Executor is idle (no tasks to poll). ExecutorID is included because it is the only identifier for the executor.

Fields

executor_id: u3


MonitorStart

Function or Scope Monitor started MonitorID identifies the monitor instance (was assigned via previous TypeDefinition event).

Fields

monitor_id: u8


MonitorEnd

Function or Scope Monitor ended MonitorID are not included here because they can be inferred from the corresponding MonitorStart event



MonitorValue

Value Monitor reported a value ValueID identifies the monitor instance (was assigned via previous TypeDefinition event). Value is the reported value payload.

Fields

value_id: u8


TypeDefinition(TypeDefinitionPayload)

Type Definition Event



DataLossEvent

Data Loss Event because of buffer full situation

Fields

dropped_events: u32


DefmtData

Fields

len: u8

Implementations

Source

impl EventPayload

pub const fn event_id(&self) -> u5

pub const fn get_executor_id(&self) -> Option<u3>

Returns the executor ID if the event is related to an embassy executor

pub const fn get_monitor_value_type_id(&self) -> Option<u3>

Returns the MonitorValuePayload type ID if the event is a MonitorValue event

pub const fn get_sub_id(&self) -> Option<u3>

Returns the sub ID (executor ID or MonitorValue type ID) if applicable

pub fn write_bytes(&self, writer: &mut BufferWriter)

pub fn from_bytes( event_type: u8, buffer: &mut BufferReader<'_>, ) -> Result<EventPayload, ReadTracingError>

Reads an EventPayload from the provided buffer based on the given type ID. Params:

  • event_type: The combined event type byte containing event ID and executor short ID.
  • buffer: The buffer reader to read additional event data from.