pub unsafe fn preinit_clock_reference()Expand description
Low-level function to get the current tracing time in microseconds. Implemented in the target crate. In tests this already should return the timedelta directly. Low-level function to preinitialize the clock reference for the target core. Implemented in the target crate. Runs in critical section.